@@ -326,14 +326,34 @@ class Page(Container):
     def extract_words(self, **kwargs: Any) -> T_obj_list:
         return utils.extract_words(self.chars, **kwargs)
 
-    def crop(self, bbox: T_bbox, relative: bool = False) -> "CroppedPage":
-        return CroppedPage(self, bbox, relative=relative)
+    def crop(
+        self, bbox: T_bbox, relative: bool = False, strict: bool = True
+    ) -> "CroppedPage":
+        return CroppedPage(self, bbox, relative=relative, strict=strict)
 
-    def within_bbox(self, bbox: T_bbox, relative: bool = False) -> "CroppedPage":
+    def within_bbox(
+        self, bbox: T_bbox, relative: bool = False, strict: bool = True
+    ) -> "CroppedPage":
         """
         Same as .crop, except only includes objects fully within the bbox
         """
-        return CroppedPage(self, bbox, relative=relative, crop_fn=utils.within_bbox)
+        return CroppedPage(
+            self, bbox, relative=relative, strict=strict, crop_fn=utils.within_bbox
+        )
+
+    def outside_bbox(
+        self, bbox: T_bbox, relative: bool = False, strict: bool = True
+    ) -> "CroppedPage":
+        """
+        Same as .crop, except only includes objects fully within the bbox
+        """
+        p = CroppedPage(
+            self, bbox, relative=relative, strict=strict, crop_fn=utils.outside_bbox
+        )
+
+        # Reset, because this operation should not actually change bbox
+        p.bbox = self.bbox
+        return p
 
     def filter(self, test_function: Callable[[T_obj], bool]) -> "FilteredPage":
         return FilteredPage(self, test_function)
@@ -422,6 +442,7 @@ class CroppedPage(DerivedPage):
         bbox: T_bbox,
         crop_fn: Callable[[T_obj_list, T_bbox], T_obj_list] = utils.crop_to_bbox,
         relative: bool = False,
+        strict: bool = True,
     ):
         if relative:
             o_x0, o_top, _, _ = parent_page.bbox
@@ -430,8 +451,14 @@ class CroppedPage(DerivedPage):
         else:
             self.bbox = bbox
 
-        test_proposed_bbox(self.bbox, parent_page.bbox)
-        self.crop_fn = crop_fn
+        if strict:
+            test_proposed_bbox(self.bbox, parent_page.bbox)
+
+        def _crop_fn(objs: T_obj_list) -> T_obj_list:
+            return crop_fn(objs, bbox)
+
+        self._crop_fn = _crop_fn
+
         super().__init__(parent_page)
 
     @property
@@ -439,7 +466,7 @@ class CroppedPage(DerivedPage):
         if hasattr(self, "_objects"):
             return self._objects
         self._objects: Dict[str, T_obj_list] = {
-            k: self.crop_fn(v, self.bbox) for k, v in self.parent_page.objects.items()
+            k: self._crop_fn(v) for k, v in self.parent_page.objects.items()
         }
         return self._objects
 
